@@ -3,7 +3,8 @@ enc_in = {
 		"{SPACE}": " ",
 		"{EQUAL}": "=",
 		"{NL}": "\n",
-		"{TAB}": "\t"
+		"{TAB}": "\t",
+		"{BR}": "<br/>"
 }
 
 enc_out = {
@@ -11,7 +12,8 @@ enc_out = {
 	" ": "{SPACE}",
 	"=": "{EQUAL}",
 	"\n": "{NL}",
-	"\t": "{TAB}"
+	"\t": "{TAB}",
+	"<br/>": "{BR}"
 }
 
 def create_node(node: dict):
